#
# spec file for package treeline
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           treeline
Version:        3.1.6
Release:        1.7
Summary:        Versatile Tree-Style Outliner for Defining Custom Data Schemas
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://treeline.bellz.org
Source0:        https://github.com/doug-101/TreeLine/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        x-%{name}.desktop
Source2:        x-%{name}-gz.desktop
Source3:        x-treepad.desktop
BuildRequires:  fdupes
BuildRequires:  perl
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
Requires:       python3-qt5
BuildArch:      noarch

%description
TreeLine is a versatile tool for working with all kinds of information
that fit into a tree-like structure.

It can be used to edit bookmark files, create mini-databases (for
example, for addresses, tasks, records, or CDs), outline documents, or
just collect ideas. It can also be used as a generic editor for XML
files.

The data schemas for any node in the data tree can be customized and
new types of nodes can be defined. The way data is presented on the
screen, exported to HTML, or printed can be defined with HTML-like
templates. Plug-ins can be written to load and save data from and to
custom file formats or external data sources and extend the
functionality of TreeLine.

TreeLine is written in Python and uses the PyQt bindings to the Qt
toolkit, which makes it very portable.

%prep
%setup -q -n TreeLine
for i in source/*.py; do
  sed -i "s|#!%{_bindir}/env python|#!%{_bindir}/python|g" "$i"
done

find source/ -type f -name '*.py' | while read f; do
    case $f in
    */treeline.py) continue;;
    esac
    perl -i -n -e 'print unless m,^#!, and 1..1' "$f"
done

%build

%install
python3 install.py -x \
   -p "%{_prefix}" \
   -i "%{_datadir}/%{name}/icons" \
   -d "%{_docdir}/%{name}" \
   -b %{buildroot}

python3 -c "import compileall; compileall.compile_dir('%{buildroot}%{_libexecdir}/treeline',2,ddir='%{_libexecdir}/treeline')"

%suse_update_desktop_file -i treeline Office ProjectManagement

install -d "%{buildroot}%{_datadir}/mimelnk/application"
install -m0644 \
    "%{SOURCE1}" \
    "%{SOURCE2}" \
    "%{SOURCE3}" \
    "%{buildroot}%{_datadir}/mimelnk/application/"

%fdupes -s "%{buildroot}%{_datadir}"

rm -f %{buildroot}%{_docdir}/%{name}/{INSTALL,LICENSE}

%files
%license doc/LICENSE
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%doc %{_docdir}/%{name}
%{_bindir}/treeline
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/48x48/apps/treeline-icon.png
%{_datadir}/icons/hicolor/scalable/apps/treeline-icon.svg
%{_datadir}/mimelnk/application/x-treeline-gz.desktop
%{_datadir}/mimelnk/application/x-treeline.desktop
%{_datadir}/mimelnk/application/x-treepad.desktop
%{_datadir}/treeline/

%changelog
* Mon Sep 18 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 3.1.6:
  * Updates:
  - Detect external file modifications by checking the file's last modified time just prior to saving.
  - Preserve the choices in the field format when switching between Choice and Combination field types.
  * Bug Fixes:
  - Fix a bug that prevented child type limits from being set back to all types.
  - Preserve the modified status of the config dialog when switching between windows displaying different files.
  - Fix problems occurring when the escape key is used to close various non-modal dialogs.
  - Avoid a traceback error message when attempting to import a CSV file with a bad header row.
  - Fix a bug using child count fields in live HTML exports.
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.5:
  * Add a command for strike-through font formatting.
  * For better visibility, increase the width of tree structure lines in printed
    and PDF output files.
  * Add a Russian translation of the GUI and the help files
  * Update the German GUI translation (thanks to Karsten).
  * Fix a bug preventing a second-try password entry from opening an encrypted file.
  * Add fallbacks to UTF-8 encoding if the OS encoding fails on import and export.
  * Avoid a crash when bad field name modifiers are in a math field equation.
* Sun Nov 29 2020 Gottfried Necker <gottfried.necker@gmx.de>
- Update to 3.1.4
  * Bug Fixes
  - Fix an incompatibility with the new Python 3.9 version under Linux
    or running from source.
  - Avoid an error message when a window is closed with the focus on a
    dialog box.
  - Fix a problem recalculating root references in field equations.
* Fri Aug 28 2020 Gottfried Necker <gottfried.necker@gmx.de>
- Update to 3.1.3
  * New Features:
  - Add a more flexible tool for customizing GUI colors.
  - Add an Insert Date command that adds a timestamp to text field edit boxes.
  - Evaluate math expressions contained in fields that are referenced by math
    field equations.
  - Add support for German outline numbering using double letters in some
    levels (thanks to Teresa M).
  * Updates:
  - Update math field equation restrictions to work with Python 3.8.
  - References to a macOS port on MacPorts were added to the System
    Requirements and Installation documentation.
  - Update the libraries used to build the Windows binaries to Python 3.8
    and Qt/PyQt 5.14.
  * Bug Fixes:
  - Make the Add Child command available after filtering has ended.
  - Avoid an application error when a Find and Replace command causes
    fields to contain invalid data.
  - Perform a more complete recalculation of math fields after certain
    operations.
  - Fix problems opening files that contain circular reference errors in
    math fields.
  - Avoid problems with empty parameters in the font dialogs.
  - Fix a bug in Data Edit views when no fields are visible due to hidden
    numbering or math fields.
  - Properly update multiple windows after drag and drop tree changes.
  - Fix issues with restoring window geometry with multiple monitors and
    changing configurations.
  - Work around bugs when using files located on some types of Windows
    network drives.
  - Fix problems detecting existing TreeLine sessions when opening files
    (mostly in Linux).
* Sun May 24 2020 Gottfried Necker <gottfried.necker@gmx.de>
- Update to 3.1.2
  * Packaging:
  - Remove pushd and popd from spec file.
  * New Features:
  - Add a simplified Chinese GUI translation
    (thanks to Qu Ray for translating).
  - Add a general option to extend the height of data editors with
    long text content. The default setting (limit the height to
    the window size) is unchanged. The new option uses the view
    scroll bars to access the full text length.
  * Updates:
  - Restore the cursor and scroll positions of data editors when
    the editors are re-created after focus changes.
  - Add an asterisk after the file name in the title bar if
    a file has been modified.
  - Change lettered outline numbering sequences to match standards.
    The sequences change from ...Y, Z, AA, AB, AC... to ...Y, Z, AA, BB, CC...
  * Bug Fixes:
  - Fix a bug that truncated plain text exports after the first line.
  - Enable the title list view's select in tree context menu to be used
    on new child nodes.
  - Modify dark mode colors to make tool tips visible.
  - Fix error due to character encoding when importing files from Treepad.
  - Fix an error caused by attempting to print an empty branch.
- changelog for 3.1.1
  * Updates:
  - Added many Show Configuration Structure data fields to show detailed
    settings for type formats and field formats.
  - Added support for finding and replacing empty data fields using the
    search and replace command.
  - Updated German and Spanish GUI translations (thanks to Maria Seliger
    and Diego).
  * Bug Fixes:
  - Fix printing problems when using the dark theme.
  - Fix incorrect numbering updates in some situations with mixed node types.
  - Fix problems defining a math field equation on a recently copied data type.
  - Eliminate a problem defining math field equations that include
    child count references.
  - Fix a minor bug affecting default directories for save-as and export
    commands when there is not already a file name set.
* Fri Sep 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.1.1 to use PyQt5 instead of PyQt4.
  * No changelog available
- Run spec-cleaner
* Tue Feb 16 2016 mkravec@suse.com
- Update to version 2.0.2
  * Bug Fixes:
  - Fixed a major regression in 2.0.1 that broke data editors for
    most specialized field types (number, math, boolean, choice, etc.)
  - Reduce the amount of work that a single undo command removes
    from editors in the data edit view.
  - Fixed a bug that prevented setting the unique ID reference
    field on a newly created data type.
  - Preserve hard newlines in text fields when converting TreeLine
    1.4.x files to this version.
  - Fix problems preserving expand/collapse node states when
    indenting and unindenting nodes.
  * Updates:
  - Added methods to the plugin interface that allow general
    program options to be queried and changed.
  - Improve text table import error messages by including the line
    number where the problem is found.
  - Modified the Treepad file import to use SpacedText fields to more
    closely match Treepad formatting.
  - An optional plugin was written that can export files to the
    Treepad text file format.
  - The TreeLine icon was replaced with a new one. Thanks to
    David Reimer for contributing the artwork.
  - The German and Portuguese GUI translations were updated.
  - Updated the long text sample file to include the SpacedText field
    type, and added a conditional equation to the math sample file.
  - Updated the Math Field section of the documentation.
* Tue Apr  7 2015 p.drouand@gmail.com
- Update to version 1.9.7
  * No changelog available
- Remove obsolete AUTHORS and %%clean sections
- Switch to python3; follow upstream changes
  * Replace python dependencies with python3 ones
  * Remove python-xml; xml is provided by python3 package
* Sun Sep 23 2012 nmo.marques@gmail.com
- Update to version 1.4.1:
  + Fixed failures due to bad internal references when opening
    encrypted files in multiple windows.
  + Avoid corruption of user option settings after attempting to
    automatically open an imported file as the last file used.
  + Fix problems with imported files when the user sets new files
    to be encrypted by default.
  + Prompt the user for a password when copying types from an
    encrypted TreeLine file.
- Sources moved to upstream format, tar.gz
- rpmlint: remove INSTALL in docs; escape macro in comment
* Sat Apr 16 2011 pascal.bleser@opensuse.org
- update to 1.4.0:
  * remembering of previous directories for path-based fields
  * addition of toolbar icons for window commands
  * correction of a column control bug in HTML export
  * ability to operate with multiple windows
  * ability to update the same file from multiple windows
  * command to add internal links to text
  * new multiple-directory HTML export
  * searchable help
  * toolbar/shortcut reset buttons to undo customizations
* Thu Aug  6 2009 joe@novell.com
- update to 1.2.3
- changes since 1.2.0:
  - minor bug fixes
  - updated German translations
  - fixes to be compatible with Python 2.6
* Thu Jun 19 2008 joe@suse.de
- update to 1.2.0
- fixed data loss issue when backup file is corrupt
- fixed minor bug in Configure Data Types dialog
* Sun Apr  6 2008 joe@suse.de
- fix DOS EOL encoding in setup.py file
* Wed Feb 13 2008 joe@suse.de
- update to 1.1.10
- fix missing shebang and remove it from rpmlintrc exceptions
* Fri Nov  9 2007 lrupp@suse.de
- fix rpmlint errors
* Wed Aug  8 2007 joe@suse.de
- update to 1.1.9
- rewrite, moved to Qt 4.x and PyQt 4.x
- basic ODF support
* Fri Aug 25 2006 joe@suse.de
- update to 1.0.0
- fixed a problem with duplicate nodes showing up when pasting
  multiple nodes on Windows
- deriving types from other derived types is no longer allowed, since
  it did not function properly
- a problem with saving an encrypted file in the German version of
  TreeLine has been fixed
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 joe@suse.de
- update to 0.14.0
* Wed Sep 21 2005 joe@suse.de
- fixed non-matching string in German translation
* Mon Aug 29 2005 joe@suse.de
- update to 0.13.0
- German and French translations
* Mon Jul 11 2005 joe@suse.de
- update to 0.12.82a
- first version that is prepared for localization
* Wed May  4 2005 joe@suse.de
- update to 0.12.0
- SUSE-specific patches are not needed any more
- Desktop icon was missing; added one from the last release
* Sun Mar 13 2005 joe@suse.de
- removing plain text files from supported mime types in .desktop
  file
* Mon Feb 28 2005 joe@suse.de
- update to 0.11.1
- removing some SUSE-specific changes that are not necessary
  any more
* Tue Feb  8 2005 joe@suse.de
- update to 0.11.0
- SUSE improvements (KDE icons)
- .desktop files are included now
- fixed dependencies
* Fri Jan 28 2005 joe@suse.de
- update to 0.10.83
- patch for documentation directory not needed any more because of
  new option in install script
* Mon Jan 24 2005 joe@suse.de
- initial checkin of TreeLine
